==> ant_1.9.7.orig.tar.xz: apache-ant-1.9.7/src/tests/junit/org/apache/tools/ant/util/UnPackageNameMapperTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.tools.ant.util;

import java.io.File;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class UnPackageNameMapperTest {

    @Test
    public void testMapping() {
        UnPackageNameMapper mapper = new UnPackageNameMapper();
        mapper.setFrom("TEST-*.xml");
        mapper.setTo("*.java");
        String file ="TEST-org.apache.tools.ant.util.UnPackageNameMapperTest.xml";
        String result = mapper.mapFileName(file)[0];
        String expected = fixupPath("org/apache/tools/ant/util/UnPackageNameMapperTest.java");

        assertEquals(expected, result);
    }

    private String fixupPath(String file) {
        return file.replace('/', File.separatorChar);
    }
}

==> ant_1.10.5.orig.tar.xz: apache-ant-1.10.5/src/tests/junit/org/apache/tools/ant/util/UnPackageNameMapperTest.java <==
/*
 *  Licensed to the Apache Software Foundation (ASF) under one or more
 *  contributor license agreements.  See the NOTICE file distributed with
 *  this work for additional information regarding copyright ownership.
 *  The ASF licenses this file to You under the Apache License, Version 2.0
 *  (the "License"); you may not use this file except in compliance with
 *  the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */
package org.apache.tools.ant.util;

import java.io.File;
import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class UnPackageNameMapperTest {

    @Test
    public void testMapping() {
        UnPackageNameMapper mapper = new UnPackageNameMapper();
        mapper.setFrom("TEST-*.xml");
        mapper.setTo("*.java");
        String file = "TEST-org.apache.tools.ant.util.UnPackageNameMapperTest.xml";
        String expected = fixupPath("org/apache/tools/ant/util/UnPackageNameMapperTest.java");

        assertEquals(expected, mapper.mapFileName(file)[0]);
    }

    private String fixupPath(String file) {
        return file.replace('/', File.separatorChar);
    }
}
